@@ -4,7 +4,7 @@ Utility library to load the underlying json library.
 Imports `orjson` or `ujson` if either is present, otherwise it imports `json` from
 the standard library.
 """
-from json_streams import file, types
+from json_streams import files, types
 
 
 def get_backend(backend_name: str):
@@ -37,7 +37,7 @@ def load_from_file(file_name: types.Pathlike, file_mode: str = "rb", **kwargs):
     :param file_name: name of the file to load from.
     :return: the loaded JSON file.
     """
-    with file.open(file_name, file_mode) as fp:
+    with files.open_file(file_name, file_mode) as fp:
         return loads(fp.read(), **kwargs)
 
 
@@ -49,5 +49,5 @@ def dump_to_file(obj, file_name: types.Pathlike, file_mode: str = "wb", **kwargs
     :param file_name: name of the file to dump to.
     :return: anything returned from the backend.
     """
-    with file.open(file_name, file_mode) as fp:
+    with files.open_file(file_name, file_mode) as fp:
         return fp.write(dumps(obj, **kwargs))
